@@ -24,6 +24,9 @@
 
 """Test that the backends return ConfigParser objects."""
 
+# This is a test suite. We know what we are checking for.
+# pylint: disable=magic-value-comparison
+
 import confget
 
 from .data import test_defs as tdefs
@@ -32,7 +35,7 @@ from .data import test_defs as tdefs
 def test_ini() -> None:
     """Test the ConfigParser object returned by the INI file backend."""
     cfg = confget.Config([], filename=tdefs.get_test_path("t3.ini"))
-    ini = confget.BACKENDS["ini"](cfg)
+    ini = confget.BACKENDS[confget.BackendType.INI](cfg)
 
     data = ini.read_file()
     assert set(data.keys()) == set(["", "a"])
